import { Component, OnInit } from '@angular/core';

@Component({
  selector: 'app-root',
  templateUrl: './app.component.html',
  styleUrls: ['./app.component.css']
})
export class AppComponent implements OnInit {
  // 页面状态
  currentPage: 'login' | 'register' | 'forgot' | 'candidate' | 'recruiter' = 'login';
  activeLoginTab: 'candidate' | 'recruiter' = 'candidate';
  activeRegisterTab: 'candidate' | 'recruiter' = 'candidate';
  activeCandidatePage: 'jobs' | 'resume' | 'interview' | 'records' | 'profile' | 'settings' = 'jobs';
  activeRecruiterPage: 'candidates' | 'jobs' | 'resume' | 'interview' | 'records' | 'analysis' | 'profile' | 'settings' = 'candidates';
  
  // 用户数据
  currentUser: any = null;
  showUserDropdown = false;
  showRecruiterDropdown = false;
  
  // 登录表单数据
  candidateLogin = { username: '', password: '' };
  recruiterLogin = { username: '', password: '' };
  
  // 注册表单数据
  candidateRegister = { username: '', password: '', confirmPassword: '', email: '' };
  recruiterRegister = { username: '', password: '', confirmPassword: '', email: '', company: '' };
  
  // 忘记密码
  forgotPasswordEmail = '';
  
  // 工作搜索
  jobSearchKeyword = '';
  showCandidateFilters = false;
  jobFilters = { type: '', location: '', salary: '', experience: '' };
  searchHistory = ['前端开发', '北京', '20k以上', '互联网'];
  hotSearches = [
    { term: 'Java开发工程师', count: '1.2万' },
    { term: '产品经理', count: '9800' },
    { term: 'UI设计师', count: '8500' },
    { term: '数据分析师', count: '7200' }
  ];
  
  // 工作数据
  jobs = [
    {
      id: 1,
      title: "高级产品经理",
      company: "XX科技公司",
      location: "北京",
      salary: "25k-40k",
      type: "全职",
      experience: "5年以上",
      skills: ["产品规划", "用户增长", "数据分析"],
      description: "负责公司核心产品的规划与设计，主导产品从0到1的开发...",
      posted: "2023-10-10",
      match: 82
    },
    // 其他工作数据...
  ];
  filteredJobs = [...this.jobs];
  
  // 候选人数据
  candidates = [
    {
      id: 1,
      name: "张伟",
      position: "高级产品经理",
      experience: "5年",
      skills: ["产品规划", "用户增长", "数据分析", "Axure", "SQL"],
      location: "北京",
      match: 82,
      resume: "张伟的简历内容..."
    },
    // 其他候选人数据...
  ];
  filteredCandidates = [...this.candidates];
  
  // 职位管理
  managedJobs = [
    {
      id: 1,
      title: "高级产品经理",
      department: "产品部",
      type: "全职",
      location: "北京",
      salary: "25k-40k",
      posted: "2023-10-01",
      applicants: 12,
      status: "招聘中"
    },
    // 其他管理职位数据...
  ];
  showJobModal = false;
  newJob = {
    title: '',
    type: 'fulltime',
    department: '',
    location: '',
    salary: '',
    description: '',
    requirements: ''
  };
  
  ngOnInit() {
    this.filteredJobs = [...this.jobs];
    this.filteredCandidates = [...this.candidates];
  }
  
  // 导航方法
  goToPage(page: 'login' | 'register' | 'forgot' | 'candidate' | 'recruiter') {
    this.currentPage = page;
  }
  
  setActiveLoginTab(tab: 'candidate' | 'recruiter') {
    this.activeLoginTab = tab;
  }
  
  setActiveRegisterTab(tab: 'candidate' | 'recruiter') {
    this.activeRegisterTab = tab;
  }
  
  // 登录/注册/忘记密码
  login(type: 'candidate' | 'recruiter') {
    const credentials = type === 'candidate' ? this.candidateLogin : this.recruiterLogin;
    
    if (!credentials.username || !credentials.password) {
      alert('请输入用户名和密码');
      return;
    }
    
    // 模拟登录成功
    this.currentUser = {
      username: credentials.username,
      type: type,
      name: type === 'candidate' ? '张伟' : '李明',
      company: type === 'recruiter' ? 'XX科技公司' : null
    };
    
    this.currentPage = type;
    this.resetForms();
  }
  
  register(type: 'candidate' | 'recruiter') {
    const form = type === 'candidate' ? this.candidateRegister : this.recruiterRegister;
    
    if (!form.username || !form.password || !form.confirmPassword || !form.email) {
      alert('请填写所有必填字段');
      return;
    }
    
    if (form.password !== form.confirmPassword) {
      alert('两次输入的密码不一致');
      return;
    }
    
    if (type === 'recruiter' && !form.company) {
      alert('请填写公司名称');
      return;
    }
    
    alert('注册成功！请登录');
    this.goToPage('login');
    this.resetForms();
  }
  
  forgotPassword() {
    if (!this.forgotPasswordEmail) {
      alert('请输入电子邮箱');
      return;
    }
    
    alert(`重置链接已发送至 ${this.forgotPasswordEmail}，请查收邮件并按照指示操作`);
    this.goToPage('login');
    this.forgotPasswordEmail = '';
  }
  
  logout() {
    this.currentUser = null;
    this.currentPage = 'login';
    this.resetForms();
  }
  
  // 应聘者页面导航
  switchCandidatePage(page: 'jobs' | 'resume' | 'interview' | 'records' | 'profile' | 'settings') {
    this.activeCandidatePage = page;
  }
  
  // 招聘者页面导航
  switchRecruiterPage(page: 'candidates' | 'jobs' | 'resume' | 'interview' | 'records' | 'analysis' | 'profile' | 'settings') {
    this.activeRecruiterPage = page;
  }
  
  // 搜索功能
  searchJobs() {
    if (!this.jobSearchKeyword) {
      this.filteredJobs = [...this.jobs];
      return;
    }
    
    const keyword = this.jobSearchKeyword.toLowerCase();
    this.filteredJobs = this.jobs.filter(job => 
      job.title.toLowerCase().includes(keyword) || 
      job.company.toLowerCase().includes(keyword) ||
      job.skills.some(skill => skill.toLowerCase().includes(keyword))
    );
    
    // 添加到搜索历史
    if (keyword && !this.searchHistory.includes(keyword)) {
      this.searchHistory.unshift(keyword);
      if (this.searchHistory.length > 5) {
        this.searchHistory.pop();
      }
    }
  }
  
  applySearchTag(tag: string) {
    this.jobSearchKeyword = tag;
    this.searchJobs();
  }
  
  // 筛选功能
  toggleCandidateFilters() {
    this.showCandidateFilters = !this.showCandidateFilters;
  }
  
  applyJobFilters() {
    let filtered = [...this.jobs];
    
    if (this.jobFilters.type) {
      filtered = filtered.filter(job => {
        if (this.jobFilters.type === 'fulltime') return job.type === '全职';
        if (this.jobFilters.type === 'parttime') return job.type === '兼职';
        if (this.jobFilters.type === 'intern') return job.type === '实习';
        return true;
      });
    }
    
    // 其他筛选条件...
    
    this.filteredJobs = filtered;
    this.showCandidateFilters = false;
  }
  
  resetJobFilters() {
    this.jobFilters = { type: '', location: '', salary: '', experience: '' };
    this.filteredJobs = [...this.jobs];
  }
  
  // 职位管理
  showJobModal() {
    this.showJobModal = true;
  }
  
  hideJobModal() {
    this.showJobModal = false;
    this.newJob = {
      title: '',
      type: 'fulltime',
      department: '',
      location: '',
      salary: '',
      description: '',
      requirements: ''
    };
  }
  
  addNewJob() {
    if (!this.newJob.title || !this.newJob.department || !this.newJob.location || !this.newJob.salary) {
      alert('请填写所有必填字段');
      return;
    }
    
    const now = new Date();
    const newJob = {
      id: this.managedJobs.length + 1,
      title: this.newJob.title,
      department: this.newJob.department,
      type: this.newJob.type === 'fulltime' ? '全职' : this.newJob.type === 'parttime' ? '兼职' : '实习',
      location: this.newJob.location,
      salary: this.newJob.salary,
      posted: `${now.getFullYear()}-${(now.getMonth()+1).toString().padStart(2, '0')}-${now.getDate().toString().padStart(2, '0')}`,
      applicants: 0,
      status: "招聘中"
    };
    
    this.managedJobs.push(newJob);
    this.hideJobModal();
  }
  
  // 其他方法
  toggleUserDropdown() {
    this.showUserDropdown = !this.showUserDropdown;
  }
  
  toggleRecruiterDropdown() {
    this.showRecruiterDropdown = !this.showRecruiterDropdown;
  }
  
  showJobDetail(jobId: number) {
    const job = this.jobs.find(j => j.id === jobId);
    if (job) {
      alert(`职位详情: ${job.title}\n公司: ${job.company}\n地点: ${job.location}\n薪资: ${job.salary}\n描述: ${job.description}`);
    }
  }
  
  private resetForms() {
    this.candidateLogin = { username: '', password: '' };
    this.recruiterLogin = { username: '', password: '' };
    this.candidateRegister = { username: '', password: '', confirmPassword: '', email: '' };
    this.recruiterRegister = { username: '', password: '', confirmPassword: '', email: '', company: '' };
    this.forgotPasswordEmail = '';
  }
}